pub fn is_function(value: &Value) -> boolExpand description
Whether value looks like a legacy function object — i.e. a JSON object
carrying stops (interval/exponential/categorical) or property (an
identity function). Other objects are not functions and remain parse errors.