pub enum FilterError {
PropertyNotString {
op: String,
},
}Expand description
A legacy filter that could not be converted to an expression.
Variants
PropertyNotString
A property operand of a legacy comparison/in/has was not a string
(legacy filters name the property with a bare string). op is the
offending operator.