pub struct Options { /* private fields */ }Expand description
Parser/runtime extension registry.
Implementations
Sourceimpl Options
impl Options
pub fn new() -> Options
Sourcepub fn convert_legacy(&mut self, enabled: bool) -> &mut Options
pub fn convert_legacy(&mut self, enabled: bool) -> &mut Options
Enable or disable transparent conversion of legacy function objects (on by default). When disabled, a bare JSON object is rejected as a parse error rather than being treated as a legacy function.
Sourcepub fn macro_def(
&mut self,
name: impl Into<String>,
params: Vec<String>,
body: Value,
) -> &mut Options
pub fn macro_def( &mut self, name: impl Into<String>, params: Vec<String>, body: Value, ) -> &mut Options
Register a macro expanded at parse time.
Sourcepub fn function(
&mut self,
name: impl Into<String>,
params: Vec<String>,
body: Value,
) -> &mut Options
pub fn function( &mut self, name: impl Into<String>, params: Vec<String>, body: Value, ) -> &mut Options
Register a function invoked at evaluation time (may recurse).